==> qbs_2.1.2.orig.tar.gz: qbs-src-2.1.2/src/lib/msbuild/msbuild/msbuildpropertygroup.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "msbuildpropertygroup.h"

#include "imsbuildnodevisitor.h"
#include "msbuildproperty.h"

namespace qbs {

class MSBuildPropertyGroupPrivate
{
public:
    QString condition;
    QString label;
};

MSBuildPropertyGroup::MSBuildPropertyGroup(MSBuildProject *parent)
    : IMSBuildGroup(parent)
    , d(new MSBuildPropertyGroupPrivate)
{
}

MSBuildPropertyGroup::~MSBuildPropertyGroup() = default;

QString MSBuildPropertyGroup::label() const
{
    return d->label;
}

void MSBuildPropertyGroup::setLabel(const QString &label)
{
    d->label = label;
}

void MSBuildPropertyGroup::appendProperty(const QString &name, const QVariant &value)
{
    new MSBuildProperty(name, value, this);
}

void MSBuildPropertyGroup::accept(IMSBuildNodeVisitor *visitor) const
{
    visitor->visitStart(this);

    for (const auto &child : children()) {
        if (const MSBuildProperty *property = qobject_cast<MSBuildProperty *>(child))
            property->accept(visitor);
    }

    visitor->visitEnd(this);
}

} // namespace qbs

==> qbs_3.1.1.orig.tar.gz: qbs-src-3.1.1/src/lib/msbuild/msbuild/msbuildpropertygroup.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "msbuildpropertygroup.h"

#include "imsbuildnodevisitor.h"
#include "msbuildproperty.h"

namespace qbs {

class MSBuildPropertyGroupPrivate
{
public:
    QString condition;
    QString label;
};

MSBuildPropertyGroup::MSBuildPropertyGroup()
    : d(new MSBuildPropertyGroupPrivate)
{
}

QString MSBuildPropertyGroup::condition() const
{
    return d->condition;
}

void MSBuildPropertyGroup::setCondition(const QString &condition)
{
    d->condition = condition;
}

MSBuildPropertyGroup::~MSBuildPropertyGroup() = default;

QString MSBuildPropertyGroup::label() const
{
    return d->label;
}

void MSBuildPropertyGroup::setLabel(const QString &label)
{
    d->label = label;
}

void MSBuildPropertyGroup::appendProperty(const QString &name, const QVariant &value)
{
    makeChild<MSBuildProperty>(name, value);
}

void MSBuildPropertyGroup::accept(IMSBuildNodeVisitor *visitor) const
{
    visitor->visitStart(this);

    acceptChildren(visitor);

    visitor->visitEnd(this);
}

} // namespace qbs
